module.exports = defineTest({
	description: 'do not fail when using labels inside functions (#1706)'
});
